==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/tr.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Etkinlik",
    "Personal activity feed for %s" : "%s kişisel etkinlik beslemesi",
    "Your feed URL is invalid" : "Besleme adresiniz geçersiz",
    "Your settings have been updated." : "Ayarlarınız güncellendi.",
    "This stream will show events like additions, changes & shares" : "Bu akış ekleme, değişiklikler ve paylaşımlar gibi etkinlikleri gösterecektir",
    "There are no events for this filter" : "Bu filtre için herhangi bir etkinlik bulunmuyor",
    "Activity notification" : "Etkinlik bildirimi",
    "All Activities" : "Tüm Etkinlikler",
    "Activities by you" : "Sizin etkinlikleriniz",
    "Activities by others" : "Başkalarının etkinlikleri",
    "\"remote user\"" : "\"uzak kullanıcı\"",
    "in %s" : "%s içinde",
    "%s and %s" : "%s ve %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s ve <strong class=\"tooltip\" title=\"%s\">%n daha fazla</strong>","%s ve <strong class=\"tooltip\" title=\"%s\">%n daha fazla</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s ve %n daha fazla","%s ve %n daha fazla"],
    "Hello %s," : "Merhaba %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Bu e-postayı alma sebebiniz son saatte %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
    "You are receiving this email because in the last day the following things happened at %s" : "Bu e-postayı alma sebebiniz son günde %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
    "You are receiving this email because in the last week the following things happened at %s" : "Bu e-postayı alma sebebiniz son haftada %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ve %n daha fazla","* ve %n daha fazla"],
    "Notifications" : "Bildirimler",
    "Mail" : "Posta",
    "Stream" : "Akış",
    "List your own actions in the stream" : "Akışta kendi eylemlerinizi listeleyin",
    "Notify about your own actions via email" : "Kendi eylemlerinizi e-posta ile alın",
    "You need to set up your email address before you can receive notification emails." : "Bildirim e-postalarını almadan önce e-posta adresinizi ayarlamanız gerekiyor.",
    "Send emails:" : "E-postaları gönder:",
    "Hourly" : "Her saat",
    "Daily" : "Her gün",
    "Weekly" : "Her hafta",
    "Activity feed" : "Etkinlik beslemesi",
    "Enable RSS feed" : "RSS beslemesini etkinleştir",
    "No activity yet" : "Henüz bir etkinlik yok",
    "No more events to load" : "Yüklenecek başka olay yok",
    "Files" : "Dosyalar"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/activity/l10n/tr.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Etkinlik",
    "Personal activity feed for %s" : "%s kişisel etkinlik beslemesi",
    "Your feed URL is invalid" : "Besleme adresiniz geçersiz",
    "Your settings have been updated." : "Ayarlarınız güncellendi.",
    "Mail" : "Posta",
    "Stream" : "Akış",
    "Activities" : "Etkinlikler",
    "Error loading activities" : "Etkinlikler yüklenirken hata oluştu",
    "No activities" : "Etkinlik yok",
    "This stream will show events like additions, changes & shares" : "Bu akış ekleme, değişiklikler ve paylaşımlar gibi etkinlikleri gösterecektir",
    "There are no events for this filter" : "Bu filtre için herhangi bir etkinlik bulunmuyor",
    "Activity notification" : "Etkinlik bildirimi",
    "All Activities" : "Tüm Etkinlikler",
    "Activities by you" : "Sizin etkinlikleriniz",
    "Activities by others" : "Başkalarının etkinlikleri",
    "\"remote user\"" : "\"uzak kullanıcı\"",
    "in %s" : "%s içinde",
    "%s and %s" : "%s ve %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s ve <strong %s>%n daha</strong>","%s ve <strong %s>%n daha</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s ve %n daha fazla","%s ve %n daha fazla"],
    "Hello %s," : "Merhaba %s,",
    "You are receiving this email because the following things happened at %s" : "Bu e-postayı alma sebebiniz %s üzerinde aşağıdaki şeylerin gerçekleşmesi:",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ve %n daha fazla","* ve %n daha fazla"],
    "Notifications" : "Bildirimler",
    "List your own actions in the stream" : "Akışta kendi eylemlerinizi listeleyin",
    "Notify about your own actions via email" : "Kendi eylemlerinizi e-posta ile alın",
    "You need to set up your email address before you can receive notification emails." : "Bildirim e-postalarını almadan önce e-posta adresinizi ayarlamanız gerekiyor.",
    "Send emails:" : "E-postaları gönder:",
    "Hourly" : "Her saat",
    "Daily" : "Her gün",
    "Weekly" : "Her hafta",
    "Activity feed" : "Etkinlik beslemesi",
    "Enable RSS feed" : "RSS beslemesini etkinleştir",
    "No activity yet" : "Henüz bir etkinlik yok",
    "No more events to load" : "Yüklenecek başka olay yok",
    "Files" : "Dosyalar",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s ve <strong class=\"has-tooltip\" title=\"%s\">%n daha</strong>","%s ve <strong class=\"has-tooltip\" title=\"%s\">%n daha</strong>"]
},
"nplurals=2; plural=(n > 1);");
